@@ -33,8 +33,17 @@ char Data[300000] = "";
 char    *Vol = "";
 char    *User = "";
 char    *Path;
-int     Version = 21;
+int     Version = 34;
 int     Mac = 0;
+char    *Test = NULL;
+
+/* Unused */
+CONN *Conn2;
+uint16_t VolID;
+int PassCount = 0;
+int FailCount = 0;
+int SkipCount = 0;
+int NotTestedCount = 0;
 
 /* Configure the tests */
 #define DIRNUM 10                                 /* 10^3 nested dirs */
@@ -45,7 +54,7 @@ static int create_enum_files = 2000;              /* 2000 files */
 
 static uint16_t vol;
 static DSI *dsi;
-static char    *Server = NULL;
+static char    *Server = "localhost";
 static int     Proto = 0;
 static int     Port = 548;
 static char    *Password = "";
@@ -155,27 +164,12 @@ static void displayresults(void)
 
 }
 
-/* ------------------------- */
-void failed(void)
-{
-    fprintf(stdout,"\tFAILED\n");
-    if (!ExitCode)
-        ExitCode = 1;
-}
-
 /* ------------------------- */
 void fatal_failed(void)
 {
-    fprintf(stdout,"\tFAILED\n");
+    fprintf(stdout,"\tFATAL ERROR\n");
     exit(1);
 }
-/* ------------------------- */
-void nottested(void)
-{
-    fprintf(stdout,"\tNOT TESTED\n");
-    if (!ExitCode)
-        ExitCode = 2;
-}
 
 /* --------------------------------- */
 int is_there(CONN *conn, int did, char *name)
@@ -355,7 +349,7 @@ void run_test(const int dir)
     if (teststorun[TEST_WRITE100MB]) {
         strcpy(temp, "File.big");
         if (FPCreateFile(Conn, vol,  0, dir , temp)){
-            failed();
+            test_failed();
             goto fin1;
         }
 
@@ -636,23 +630,25 @@ fin:
 void usage( char * av0 )
 {
     int i=0;
-    fprintf( stdout, "usage:\t%s -h host [-vVgG34567] [-p port] [-s vol] [-u user] [-w password] [-n iterations] [-t tests to run] [-F bigfile]\n", av0 );
-    fprintf( stdout,"\t-h\tserver host name\n");
+    fprintf( stdout, "usage:\t%s [-34567GgVv] [-h host] [-p port] [-s vol] [-u user] [-w password] "
+    "[-n iterations] [-f tests] [-F bigfile]\n", av0 );
+    fprintf( stdout,"\t-h\tserver host name (default localhost)\n");
     fprintf( stdout,"\t-p\tserver port (default 548)\n");
-    fprintf( stdout,"\t-s\tvolume to mount (default home)\n");
+    fprintf( stdout,"\t-s\tvolume to mount\n");
     fprintf( stdout,"\t-u\tuser name (default uid)\n");
-    fprintf( stdout,"\t-w\tpassword (default none)\n");
+    fprintf( stdout,"\t-w\tpassword\n");
     fprintf( stdout,"\t-3\tAFP 3.0 version\n");
     fprintf( stdout,"\t-4\tAFP 3.1 version\n");
-    fprintf( stdout,"\t-5\tAFP 3.2 version (default)\n");
+    fprintf( stdout,"\t-5\tAFP 3.2 version\n");
     fprintf( stdout,"\t-6\tAFP 3.3 version\n");
-    fprintf( stdout,"\t-7\tAFP 3.4 version\n");
+    fprintf( stdout,"\t-7\tAFP 3.4 version (default)\n");
     fprintf( stdout,"\t-n\thow many iterations to run (default: 1)\n");
     fprintf( stdout,"\t-v\tverbose\n");
     fprintf( stdout,"\t-V\tvery verbose\n");
+    fprintf( stdout,"\t-b\tdebug mode\n");
     fprintf( stdout,"\t-g\tfast network (Gbit, file testsize 1 GB)\n");
     fprintf( stdout,"\t-G\tridiculously fast network (10 Gbit, file testsize 10 GB)\n");
-    fprintf( stdout,"\t-t\ttests to run, eg 134 for tests 1, 3 and 4\n");
+    fprintf( stdout,"\t-f\ttests to run, eg 134 for tests 1, 3 and 4\n");
     fprintf( stdout,"\t-F\tuse this file located in the volume root for the read test (size must match -g and -G options)\n");
     fprintf( stdout,"\tAvailable tests:\n");
     for (i = 0; i < NUMTESTS; i++)
@@ -665,20 +661,11 @@ int main(int ac, char **av)
 {
     int cc, i, t;
     int Debug = 0;
-    char *tests = NULL;
-    // FIXME: this test relies on mismatched Version=21 and AFP3.2 version string
-    static char *vers = "AFP3.2";
+    static char *vers = "AFP3.4";
     static char *uam = "Cleartxt Passwrd";
-    struct passwd *pw = getpwuid(getuid());
 
-    if (pw)
-        User = strdup(pw->pw_name);
-
-    while (( cc = getopt( ac, av, "t:vVgG34567h:n:p:s:u:w:c:F:" )) != EOF ) {
+    while (( cc = getopt( ac, av, "1234567bGgVvF:f:h:n:p:s:u:w:" )) != EOF ) {
         switch ( cc ) {
-        case 't':
-            tests = strdup(optarg);
-            break;
         case '3':
             vers = "AFPX03";
             Version = 30;
@@ -699,22 +686,26 @@ int main(int ac, char **av)
 			vers = "AFP3.4";
 			Version = 34;
 			break;
-        case 'n':
-            Iterations = atoi(optarg);
+        case 'b':
+            Debug = 1;
+            break;
+        case 'F':
+            bigfilename = strdup(optarg);
+            break;
+        case 'f':
+            Test = strdup(optarg);
+            break;
+        case 'G':
+            rwsize *= 100;
+            break;
+        case 'g':
+            rwsize *= 10;
             break;
         case 'h':
             Server = strdup(optarg);
             break;
-        case 's':
-            Vol = strdup(optarg);
-            break;
-        case 'u':
-            if (User)
-                free(User);
-            User = strdup(optarg);
-            break;
-        case 'w':
-            Password = strdup(optarg);
+        case 'n':
+            Iterations = atoi(optarg);
             break;
         case 'p' :
             Port = atoi( optarg );
@@ -723,46 +714,74 @@ int main(int ac, char **av)
                 exit(1);
             }
             break;
-        case 'v':
-            Debug = 1;
+        case 's':
+            Vol = strdup(optarg);
+            break;
+        case 'u':
+            User = strdup(optarg);
             break;
         case 'V':
+            Quiet = 0;
             Verbose = 1;
             break;
-        case 'g':
-            rwsize *= 10;
+        case 'v':
+            Quiet = 0;
             break;
-        case 'G':
-            rwsize *= 100;
-            break;
-        case 'F':
-            bigfilename = strdup(optarg);
+        case 'w':
+            Password = strdup(optarg);
             break;
         default :
             usage( av[ 0 ] );
         }
     }
 
-    if (! Server)
-        usage( av[ 0 ] );
+    if (User[0] == '\0') {
+        struct passwd pwd;
+        struct passwd *result = NULL;
+        uid_t uid = geteuid();
+        char buf[1024];
+        int ret;
+
+        ret = getpwuid_r(uid, &pwd, buf, sizeof(buf), &result);
+
+        if (ret == 0 && result != NULL) {
+            User = pwd.pw_name;
+            printf("Using current user: %s\n", User);
+        }
+    }
+
+    if (!Quiet) {
+        fprintf(stdout, "Connecting to host %s:%d\n", Server, Port);
+    }
+	if (User != NULL && User[0] == '\0') {
+        fprintf(stdout, "Error: Define a user with -u\n");
+	}
+	if (Password != NULL && Password[0] == '\0') {
+        fprintf(stdout, "Error: Define a password with -w\n");
+	}
+	if (Vol != NULL && Vol[0] == '\0') {
+        fprintf(stdout, "Error: Define a volume with -s\n");
+	}
 
     if (! Debug) {
-        Verbose = 0;
         freopen("/dev/null", "w", stdout);
     }
 
+// FIXME: guest auth leads to broken DSI request
+#if 0
     if ((User[0] == 0) || (Password[0] == 0))
         uam = "No User Authent";
+#endif
 
     Iterations_save = Iterations;
     results = calloc(Iterations * NUMTESTS, sizeof(unsigned long));
 
-    if (!tests) {
+    if (!Test) {
         memset(teststorun, 1, NUMTESTS);
     } else {
         i = 0;
-        for (; tests[i]; i++) {
-            t = tests[i] - '1';
+        for (; Test[i]; i++) {
+            t = Test[i] - '1';
             if ((t >= 0) && (t <= NUMTESTS))
                 teststorun[t] = 1;
         }
@@ -770,6 +789,7 @@ int main(int ac, char **av)
             teststorun[TEST_WRITE100MB] = 1;
         if (teststorun[TEST_ENUM2000FILES])
             teststorun[TEST_CREATE2000FILES] = 1;
+        free(Test);
     }
 
     if ((Conn = (CONN *)calloc(1, sizeof(CONN))) == NULL)
@@ -796,7 +816,7 @@ int main(int ac, char **av)
 
     vol  = FPOpenVol(Conn, Vol);
     if (vol == 0xffff) {
-        nottested();
+        test_nottested();
     }
 
     int dir;
