@@ -38,10 +38,13 @@ static char    *Password = "";
 char    *Vol = "";
 char    *Vol2 = "";
 char    *User;
-int     Version = 21;
+int     Version = 34;
 char    *Test = "Write";
 static char    *Filename;
 
+char *vers = "AFP3.4";
+char *uam = "Cleartxt Passwrd";
+
 static int Count = 1;
 static off_t Size = 64* MEGABYTE;
 static size_t Quantum = 0;
@@ -56,6 +59,10 @@ static int Direct = 0;
 /* not used */
 CONN *Conn2;
 int  Mac = 0;
+int PassCount = 0;
+int FailCount = 0;
+int SkipCount = 0;
+int NotTestedCount = 0;
 
 struct vfs {
 	unsigned int (*getfiledirparams)(CONN *, uint16_t , int , char *, uint16_t, uint16_t);
@@ -268,13 +275,14 @@ int flags = O_RDWR;
 	}
 	did = ntohl(did);
 	if (local_chdir(vol, did) < 0) {
-		return ntohl(AFPERR_PARAM);
+		return (uint16_t) ntohl(AFPERR_PARAM);
 	}
 	fd = open(name, flags, 0666);
 	if (fd == -1) {
-		return ntohl(AFPERR_NOOBJ);
+		return (uint16_t) ntohl(AFPERR_NOOBJ);
 	}
-	return fd;
+	close(fd);
+	return (uint16_t) ntohl(AFP_OK);
 }
 
 /* ------------------------------- */
@@ -442,28 +450,6 @@ static void press_enter(char *s)
 	;
 }
 
-/* ------------------------- */
-void failed(void)
-{
-	fprintf(stdout,"\tFAILED\n");
-	if (!ExitCode)
-		ExitCode = 1;
-}
-
-/* ------------------------- */
-void fatal_failed(void)
-{
-	fprintf(stdout,"\tFAILED\n");
-	exit(1);
-}
-/* ------------------------- */
-void nottested(void)
-{
-	fprintf(stdout,"\tNOT TESTED\n");
-	if (!ExitCode)
-		ExitCode = 2;
-}
-
 /* --------------------------------- */
 int is_there(CONN *conn, uint16_t vol, int did, char *name)
 {
@@ -530,15 +516,15 @@ DSI *dsi;
 	sprintf(temp,"WriteTest-%d", id);
 
 	if (ntohl(AFPERR_NOOBJ) != is_there(Conn, VolID, DIRDID_ROOT, temp)) {
-		nottested();
+		test_nottested();
 		return;
 	}
 	if (!(dir = VFS.createdir(Conn,vol, DIRDID_ROOT , temp))) {
-		nottested();
+		test_nottested();
 		goto fin;
 	}
 	if (VFS.createfile(Conn, vol,  0, dir , "File")){
-		failed();
+		test_failed();
 		goto fin;
 	}
 
@@ -546,7 +532,7 @@ DSI *dsi;
 	for (i = 1; i <= Count; i++) {
 		fork = VFS.openfork(Conn, vol, OPENFORK_DATA , (1<<FILPBIT_FNUM), dir, "File", OPENACC_WR |OPENACC_RD| OPENACC_DWR| OPENACC_DRD);
 		if (!fork) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		fprintf(stdout,"%d\t", i);
@@ -560,7 +546,7 @@ DSI *dsi;
 	    	    nbe = written;
 		    }
 		    if (push < Request && VFS.writeheader(dsi, fork, offset, nbe, Buffer, 0)) {
-				failed();
+				test_failed();
 				goto fin1;
 			}
 			written -= nbe;
@@ -571,7 +557,7 @@ DSI *dsi;
 	    	    	nbe_r = written_r;
 		    	}
 				if (VFS.writefooter(dsi, fork, offset_r, nbe_r, Buffer, 0)) {
-		    		failed();
+		    		test_failed();
 		    		goto fin1;
 				}
 				push--;
@@ -584,7 +570,7 @@ DSI *dsi;
 	    		nbe_r = written_r;
 		    }
 			if (VFS.writefooter(dsi, fork, offset_r, nbe_r, Buffer, 0)) {
-		    	failed();
+		    	test_failed();
 		    	goto fin1;
 			}
 			push--;
@@ -592,29 +578,29 @@ DSI *dsi;
 			offset_r += nbe_r;
 		}
 		if (Flush && VFS.flushfork(Conn, fork)) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		timer_footer();
 		if (VFS.closefork(Conn,fork)) {
-			failed();
+			test_failed();
 			goto fin;
 		}
 		fork = 0;
 
 		if (Delete) {
 			if (VFS.delete(Conn, vol,  dir, "File") || VFS.createfile(Conn, vol,  0, dir , "File")){
-				failed();
+				test_failed();
 				goto fin;
 			}
 		}
 	}
 
 fin1:
-	if (fork && VFS.closefork(Conn,fork)) {failed();}
-	if (VFS.delete(Conn, vol,  dir, "File")) {failed();}
+	if (fork && VFS.closefork(Conn,fork)) {test_failed();}
+	if (VFS.delete(Conn, vol,  dir, "File")) {test_failed();}
 fin:
-	if (VFS.delete(Conn, vol,  dir, "")) {failed();}
+	if (VFS.delete(Conn, vol,  dir, "")) {test_failed();}
     fprintf(stdout, "\n");
 	return;
 }
@@ -720,37 +706,37 @@ int cnt = 0;
 	sprintf(temp,"CopyTest-%d", id);
 	if (!Filename) {
 		if (ntohl(AFPERR_NOOBJ) != is_there(Conn, VolID, DIRDID_ROOT, temp)) {
-			nottested();
+			test_nottested();
 			return;
 		}
 	}
 	else {
 		dir = DIRDID_ROOT;
 		if (ntohl(AFP_OK) != is_there(Conn, VolID, dir, Filename)) {
-			nottested();
+			test_nottested();
 			return;
 		}
 	}
 	if (VolID != VolID2 && ntohl(AFPERR_NOOBJ) != is_there(Conn, VolID2, DIRDID_ROOT, temp)) {
-		nottested();
+		test_nottested();
 		return;
 	}
 
 	if (!Filename && !(dir = VFS.createdir(Conn,vol, DIRDID_ROOT , temp))) {
-		nottested();
+		test_nottested();
 		goto fin;
 	}
 	if (VolID == VolID2) {
 		dir2 = dir;
 	}
 	else if (!(dir2 = VFS.createdir(Conn, vol2, DIRDID_ROOT , temp))) {
-		nottested();
+		test_nottested();
 		goto fin;
 	}
 	if (!Filename) {
 		strcpy(temp, "Source");
 		if (VFS.createfile(Conn, vol,  0, dir , temp)){
-			failed();
+			test_failed();
 			goto fin;
 		}
 	}
@@ -758,24 +744,24 @@ int cnt = 0;
 		strcpy(temp, Filename);
 	}
 	if (VFS.createfile(Conn, vol2,  0, dir2 , "Destination")){
-		failed();
+		test_failed();
 		goto fin;
 	}
 
 	for (i = 1; i <= Count; i++) {
 		fork = VFS.openfork(Conn, vol, OPENFORK_DATA , (1<<FILPBIT_FNUM), dir, temp, OPENACC_WR |OPENACC_RD| OPENACC_DWR| OPENACC_DRD);
 		if (!fork) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		fork2 = VFS.openfork(Conn, vol2, OPENFORK_DATA , (1<<FILPBIT_FNUM), dir2, "Destination", OPENACC_WR |OPENACC_RD| OPENACC_DWR| OPENACC_DRD);
 		if (!fork2) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		if (!Filename && (i == 1 || Delete)) {
 			if (init_fork(fork)) {
-				failed();
+				test_failed();
 				goto fin1;
 			}
 		}
@@ -796,7 +782,7 @@ int cnt = 0;
 		    }
 		    cnt++;
 		    if (push < max && VFS.readheader(dsi, fork, offset, nbe, Buffer)) {
-		    	failed();
+		    	test_failed();
 		    	goto fin1;
 		    }
 			written -= nbe;
@@ -807,16 +793,16 @@ int cnt = 0;
 	    	    	nbe_r = written_r;
 		    	}
 				if (VFS.readfooter(dsi, fork, offset_r, nbe_r, Buffer)) {
-		    		failed();
+		    		test_failed();
 		    		goto fin1;
 				}
 		    	if (VFS.writeheader(dsi, fork2, offset_r, nbe_r, Buffer, 0)) {
-					failed();
+					test_failed();
 					goto fin1;
 				}
 				if (cnt >= max*2 -1 ) {
 					if (VFS.writefooter(dsi, fork2, offset_w, nbe_w, Buffer, 0)) {
-		    			failed();
+		    			test_failed();
 		    			goto fin1;
 		    		}
 					written_w -= nbe_w;
@@ -832,15 +818,15 @@ int cnt = 0;
 	    		nbe_r = written_r;
 		    }
 			if (VFS.readfooter(dsi, fork, offset_r, nbe_r, Buffer)) {
-		    	failed();
+		    	test_failed();
 		    	goto fin1;
 			}
 			if (VFS.writeheader(dsi, fork2, offset_r, nbe_r, Buffer, 0)) {
-				failed();
+				test_failed();
 				goto fin1;
 			}
 			if (VFS.writefooter(dsi, fork2, offset_w, nbe_w, Buffer, 0)) {
-		    	failed();
+		    	test_failed();
 		    	goto fin1;
 			}
 			push--;
@@ -854,7 +840,7 @@ int cnt = 0;
 	    		nbe_w = written_w;
 		    }
 			if (VFS.writefooter(dsi, fork2, offset_w, nbe_w, Buffer, 0)) {
-		    	failed();
+		    	test_failed();
 		    	goto fin1;
 			}
 			written_w -= nbe_w;
@@ -862,12 +848,12 @@ int cnt = 0;
 		}
 		timer_footer();
 		if (VFS.closefork(Conn,fork)) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		fork = 0;
 		if (VFS.closefork(Conn,fork2)) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		fork2 = 0;
@@ -881,24 +867,24 @@ int cnt = 0;
 			}
 
 			if (!Filename && VFS.createfile(Conn, vol,  0, dir , temp)){
-				failed();
+				test_failed();
 				goto fin;
 			}
 			if (VFS.createfile(Conn, vol2,  0, dir2 , "Destination")){
-				failed();
+				test_failed();
 				goto fin;
 			}
 		}
 	}
 
 fin1:
-	if (fork && VFS.closefork(Conn,fork)) {failed();}
-	if (fork2 && VFS.closefork(Conn,fork2)) {failed();}
-	if (!Filename && VFS.delete(Conn, vol,  dir, temp)) {failed();}
-	if (VFS.delete(Conn, vol2,  dir2, "Destination")) {failed();}
+	if (fork && VFS.closefork(Conn,fork)) {test_failed();}
+	if (fork2 && VFS.closefork(Conn,fork2)) {test_failed();}
+	if (!Filename && VFS.delete(Conn, vol,  dir, temp)) {test_failed();}
+	if (VFS.delete(Conn, vol2,  dir2, "Destination")) {test_failed();}
 fin:
-	if (!Filename && dir && VFS.delete(Conn, vol,  dir, "")) {failed();}
-	if (dir2 && dir2 != dir && VFS.delete(Conn, vol2,  dir2, "")) {failed();}
+	if (!Filename && dir && VFS.delete(Conn, vol,  dir, "")) {test_failed();}
+	if (dir2 && dir2 != dir && VFS.delete(Conn, vol2,  dir2, "")) {test_failed();}
 
 	return;
 }
@@ -920,77 +906,77 @@ int i;
 
 	sprintf(temp,"ServerCopyTest-%d", id);
 	if (ntohl(AFPERR_NOOBJ) != is_there(Conn, VolID, DIRDID_ROOT, temp)) {
-		nottested();
+		test_nottested();
 		return;
 	}
 	if (VolID != VolID2 && ntohl(AFPERR_NOOBJ) != is_there(Conn, VolID2, DIRDID_ROOT, temp)) {
-		nottested();
+		test_nottested();
 		return;
 	}
 
 	if (!(dir = VFS.createdir(Conn,vol, DIRDID_ROOT , temp))) {
-		nottested();
+		test_nottested();
 		goto fin;
 	}
 	if (VolID == VolID2) {
 		dir2 = dir;
 	}
 	else if (!(dir2 = VFS.createdir(Conn, vol2, DIRDID_ROOT , temp))) {
-		nottested();
+		test_nottested();
 		goto fin;
 	}
 
 	if (VFS.createfile(Conn, vol,  0, dir , "Source")){
-		failed();
+		test_failed();
 		goto fin;
 	}
 	for (i = 1; i <= Count; i++) {
 		fork = VFS.openfork(Conn, vol, OPENFORK_DATA , (1<<FILPBIT_FNUM), dir, "Source", OPENACC_WR |OPENACC_RD );
 		if (!fork) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		if (i == 1 || Delete) {
 			if (init_fork(fork)) {
-				failed();
+				test_failed();
 				goto fin1;
 			}
 		}
 		if (VFS.closefork(Conn,fork)) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		fork = 0;
 		fprintf(stdout,"%d\t", i);
 		gettimeofday(&Timer_start, NULL);
 		if (VFS.copyfile(Conn, vol, dir, vol2, dir2, "Source", "", "Destination")) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		timer_footer();
 		if (Delete) {
 			if (VFS.delete(Conn, vol,  dir, "Source")) {
-				failed();
+				test_failed();
 				goto fin;
 			}
 			if (VFS.createfile(Conn, vol,  0, dir , "Source")){
-				failed();
+				test_failed();
 				goto fin;
 			}
 		}
 		if (VFS.delete(Conn, vol2,  dir2, "Destination")) {
-			failed();
+			test_failed();
 			goto fin;
 		}
 	}
 
 fin1:
-	if (fork && VFS.closefork(Conn,fork)) {failed();}
-	if (VFS.delete(Conn, vol,  dir, "Source")) {failed();}
+	if (fork && VFS.closefork(Conn,fork)) {test_failed();}
+	if (VFS.delete(Conn, vol,  dir, "Source")) {test_failed();}
 	VFS.delete(Conn, vol2,  dir2, "Destination");
 fin:
-	if (dir && VFS.delete(Conn, vol,  dir, "")) {failed();}
-	if (dir2 && dir2 != dir && VFS.delete(Conn, vol2,  dir2, "")) {failed();}
+	if (dir && VFS.delete(Conn, vol,  dir, "")) {test_failed();}
+	if (dir2 && dir2 != dir && VFS.delete(Conn, vol2,  dir2, "")) {test_failed();}
 
 	return;
 }
@@ -1020,16 +1006,16 @@ int push;
 		sprintf(temp,"ReadTest-%d", id);
 
 		if (ntohl(AFPERR_NOOBJ) != is_there(Conn, VolID, DIRDID_ROOT, temp)) {
-			nottested();
+			test_nottested();
 			return;
 		}
 
 		if (!(dir = VFS.createdir(Conn,vol, DIRDID_ROOT , temp))) {
-			nottested();
+			test_nottested();
 			goto fin;
 		}
 		if (VFS.createfile(Conn, vol,  0, dir , "File")){
-			failed();
+			test_failed();
 			goto fin;
 		}
 		strcpy(temp, "File");
@@ -1038,7 +1024,7 @@ int push;
 		dir = DIRDID_ROOT;
 		strcpy(temp, Filename);
 		if (ntohl(AFP_OK) != is_there(Conn, VolID, dir, temp)) {
-			nottested();
+			test_nottested();
 			return;
 		}
 	}
@@ -1046,12 +1032,12 @@ int push;
 	for (i = 1; i <= Count; i++) {
 		fork = VFS.openfork(Conn, vol, OPENFORK_DATA , (1<<FILPBIT_FNUM), dir, temp, OPENACC_WR |OPENACC_RD| OPENACC_DWR| OPENACC_DRD);
 		if (!fork) {
-			failed();
+			test_failed();
 			goto fin1;
 		}
 		if (!Filename && (i == 1 || Delete)) {
 			if (init_fork(fork)) {
-				failed();
+				test_failed();
 				goto fin1;
 			}
 		}
@@ -1068,7 +1054,7 @@ int push;
 	    	    nbe = written;
 		    }
 		    if (push < Request && VFS.readheader(dsi, fork, offset, nbe, Buffer)) {
-		    	failed();
+		    	test_failed();
 		    	goto fin1;
 		    }
 			written -= nbe;
@@ -1079,7 +1065,7 @@ int push;
 	    	    	nbe_r = written_r;
 		    	}
 				if (VFS.readfooter(dsi, fork, offset_r, nbe_r, Buffer)) {
-		    		failed();
+		    		test_failed();
 		    		goto fin1;
 				}
 				push--;
@@ -1092,7 +1078,7 @@ int push;
 	    		nbe_r = written_r;
 		    }
 			if (VFS.readfooter(dsi, fork, offset_r, nbe_r, Buffer)) {
-		    	failed();
+		    	test_failed();
 		    	goto fin1;
 			}
 			push--;
@@ -1101,7 +1087,7 @@ int push;
 		}
 		timer_footer();
 
-		if (VFS.closefork(Conn,fork)) {failed();}
+		if (VFS.closefork(Conn,fork)) {test_failed();}
 		fork = 0;
 
 		if (!Filename && Delete) {
@@ -1110,17 +1096,17 @@ int push;
 			}
 
 			if (VFS.createfile(Conn, vol,  0, dir , temp)){
-				failed();
+				test_failed();
 				goto fin;
 			}
 		}
 	}
 
 fin1:
-	if (fork && VFS.closefork(Conn,fork)) {failed();}
-	if (!Filename && VFS.delete(Conn, vol,  dir, temp)) {failed();}
+	if (fork && VFS.closefork(Conn,fork)) {test_failed();}
+	if (!Filename && VFS.delete(Conn, vol,  dir, temp)) {test_failed();}
 fin:
-	if (!Filename && VFS.delete(Conn, vol,  dir, "")) {failed();}
+	if (!Filename && VFS.delete(Conn, vol,  dir, "")) {test_failed();}
 
 	return;
 }
@@ -1163,7 +1149,7 @@ void (*fn)(void) = NULL;
 #ifdef BROKEN_DL
 	fn = test_to_run(token);
 	if (fn == -1) {
-	    nottested();
+	    test_nottested();
 	    return;
 	}
 #else
@@ -1178,7 +1164,7 @@ void (*fn)(void) = NULL;
         fprintf (stdout, "%s\n", dlerror());
     }
     if (!handle || !fn) {
-	    nottested();
+	    test_nottested();
 	    return;
 	}
 #endif
@@ -1186,13 +1172,13 @@ void (*fn)(void) = NULL;
 	press_enter("Opening volume.");
 	VolID = VFS.openvol(Conn, Vol);
 	if (VolID == 0xffff) {
-		nottested();
+		test_nottested();
 		return;
 	}
 	if (*Vol2) {
 		VolID2 = VFS.openvol(Conn, Vol2);
 		if (VolID2 == 0xffff) {
-			nottested();
+			test_nottested();
 			return;
 		}
 	}
@@ -1271,27 +1257,27 @@ void (*fn)(void) = NULL;
 /* =============================== */
 void usage( char * av0 )
 {
-    fprintf( stdout, "usage:\t%s [-h host] [-p port] [-s vol] [-S Vol2] [-u user] [-w password] [-f test] [-c count] "
-    "[-d size] [-q quantum] [-F file] [-1234567LvViyea] \n", av0 );
+    fprintf( stdout, "usage:\t%s [-1234567aeLnVvy] [-h host] [-p port] [-s vol] [-S vol2] [-u user] [-w password] [-n iterations] "
+    "[-d size] [-q quantum] [-f test] [-F file] \n", av0 );
     fprintf( stdout,"\t-h\tserver host name (default localhost)\n");
     fprintf( stdout,"\t-p\tserver port (default 548)\n");
-    fprintf( stdout,"\t-s\tvolume to mount (default home)\n");
-    fprintf( stdout,"\t-S\tsecond volume to mount (default none)\n");
+    fprintf( stdout,"\t-s\tvolume to mount\n");
+    fprintf( stdout,"\t-S\tsecond volume to mount\n");
     fprintf( stdout,"\t-u\tuser name (default uid)\n");
+    fprintf( stdout,"\t-w\tpassword\n");
 
     fprintf( stdout,"\t-L\tuse posix calls (default AFP calls)\n");
     fprintf( stdout,"\t-D\twith -L use O_DIRECT in open flags (default no)\n");
 
-    fprintf( stdout,"\t-w\tpassword (default none)\n");
-    fprintf( stdout,"\t-1\tAFP 2.1 version (default)\n");
+    fprintf( stdout,"\t-1\tAFP 2.1 version\n");
     fprintf( stdout,"\t-2\tAFP 2.2 version\n");
     fprintf( stdout,"\t-3\tAFP 3.0 version\n");
     fprintf( stdout,"\t-4\tAFP 3.1 version\n");
     fprintf( stdout,"\t-5\tAFP 3.2 version\n");
     fprintf( stdout,"\t-6\tAFP 3.3 version\n");
-    fprintf( stdout,"\t-7\tAFP 3.4 version\n");
+    fprintf( stdout,"\t-7\tAFP 3.4 version (default)\n");
 
-    fprintf( stdout,"\t-c\trun test count times\n");
+    fprintf( stdout,"\t-n\thow many iterations to run (default: 1)\n");
     fprintf( stdout,"\t-d\tfile size (Mbytes, default 64)\n");
     fprintf( stdout,"\t-q\tpacket size (Kbytes, default server quantum)\n");
     fprintf( stdout,"\t-r\tnumber of outstanding requests (default 1)\n");
@@ -1309,50 +1295,13 @@ void usage( char * av0 )
     exit (1);
 }
 
-char *vers = "AFPVersion 2.1";
-char *uam = "Cleartxt Passwrd";
 /* ------------------------------- */
 int main( int ac, char **av )
 {
 int cc;
 
-	Quiet = 1;
-    while (( cc = getopt( ac, av, "Vv1234567h:p:s:S:u:d:w:f:ic:""o:q:r:yeLDaF:R:" )) != EOF ) {
+    while (( cc = getopt( ac, av, "1234567aeDiLnVvyc:d:F:f:h:o:p:q:R:r:S:s:u:w:" )) != EOF ) {
         switch ( cc ) {
-		case 'd':
-			Size = atoi(optarg) * MEGABYTE;
-			break;
-		case 'q':
-			Quantum = atoi(optarg) *KILOBYTE;
-			break;
-		case 'r':
-			Request = atoi(optarg);
-			break;
-		case 'R':
-			Req = atoi(optarg);
-			break;
-		case 'y':
-			Delete = 1;
-			break;
-		case 'e':
-			Sparse = 1;
-			break;
-		case 'L':
-			Local = 1;
-			break;
-		case 'D':
-			Direct = 1;
-			break;
-		case 'a':
-			Flush = 0;
-			break;
-		case 'c':
-			Count = atoi(optarg);
-			break;
-		case 'F':
-            Filename = strdup(optarg);
-            break;
-
         case '1':
 			vers = "AFPVersion 2.1";
 			Version = 21;
@@ -1381,27 +1330,41 @@ int cc;
 			vers = "AFP3.4";
 			Version = 34;
 			break;
-        case 'n':
-            Proto = 1;
-            break;
-        case 'h':
-            Server = strdup(optarg);
-            break;
-        case 's':
-            Vol = strdup(optarg);
-            break;
-        case 'S':
-            Vol2 = strdup(optarg);
-            break;
-        case 'u':
-            User = strdup(optarg);
-            break;
-        case 'w':
-            Password = strdup(optarg);
+		case 'a':
+			Flush = 0;
+			break;
+		case 'D':
+			Direct = 1;
+			break;
+		case 'd':
+			Size = atoi(optarg) * MEGABYTE;
+			break;
+		case 'e':
+			Sparse = 1;
+			break;
+		case 'F':
+            Filename = strdup(optarg);
             break;
         case 'f' :
             Test = strdup(optarg);
             break;
+        case 'h':
+            Server = strdup(optarg);
+            break;
+		case 'i':
+			Interactive = 1;
+			break;
+		case 'L':
+			Local = 1;
+			break;
+		case 'n':
+			Count = atoi(optarg);
+			break;
+#if 0
+        case 'n':
+            Proto = 1;
+            break;
+#endif
         case 'p' :
             Port = atoi( optarg );
             if (Port <= 0) {
@@ -1409,22 +1372,55 @@ int cc;
                 exit(1);
             }
             break;
-	case 'v':
-		Quiet = 0;
-		break;
-	case 'V':
-		Quiet = 0;
-		Verbose = 1;
-		break;
-	case 'i':
-		Interactive = 1;
-		break;
-
+		case 'q':
+			Quantum = atoi(optarg) *KILOBYTE;
+			break;
+		case 'R':
+			Req = atoi(optarg);
+			break;
+		case 'r':
+			Request = atoi(optarg);
+			break;
+        case 'S':
+            Vol2 = strdup(optarg);
+            break;
+        case 's':
+            Vol = strdup(optarg);
+            break;
+        case 'u':
+            User = strdup(optarg);
+            break;
+		case 'V':
+			Quiet = 0;
+			Verbose = 1;
+			break;
+		case 'v':
+			Quiet = 0;
+			break;
+        case 'w':
+            Password = strdup(optarg);
+            break;
+		case 'y':
+			Delete = 1;
+			break;
         default :
             usage( av[ 0 ] );
         }
     }
 
+    if (!Quiet) {
+        fprintf(stdout, "Connecting to host %s:%d\n", Server, Port);
+    }
+	if (User != NULL && User[0] == '\0') {
+        fprintf(stdout,"Error: Define a user with -u\n");
+	}
+	if (Password != NULL && Password[0] == '\0') {
+        fprintf(stdout,"Error: Define a password with -w\n");
+	}
+	if (Vol != NULL && Vol[0] == '\0') {
+        fprintf(stdout,"Error: Define a volume with -s\n");
+	}
+
 	/**************************
 	 Connection */
 
@@ -1450,8 +1446,6 @@ int cc;
     	 	Dsi->protocol = DSI_TCPIP;
 	    	Dsi->socket = sock;
 	    }
-    	else {
-		}
 
 	    /* login */
     	if (Version >= 30) {
@@ -1465,8 +1459,6 @@ int cc;
 
 	/*********************************
 	*/
-	if (Verbose)
-		Quiet = 0;
 	run_one(Test);
 	if (!Local)
    		FPLogOut(Conn);
